/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'ar', {
	border: 'إظهار حدود الإطار',
	noUrl: 'فضلا أكتب رابط الـ iframe',
	scrolling: 'تفعيل أشرطة الإنتقال',
	title: 'خصائص iframe',
	toolbar: 'iframe',
	tabindex: 'Remove from tabindex' // MISSING
} );
